@@ -14,13 +14,13 @@ def init_stroller_model(app_DBSession, app_DeclarativeBase, app_User, app_Group)
     User=app_User
     Group=app_Group
     
-    from commerce import Product, Category, Order, OrderItem, ProductInfo
+    from commerce import Product, Category, Order, OrderItem, ProductInfo, ProductPhoto
     return Product, ProductInfo, Category, Order, OrderItem
     
 def setup_stroller_database(app_DBSession, app_DeclarativeBase,
                              User, Group):                         
     init_stroller_model(app_DBSession, app_DeclarativeBase, User, Group)
-    from commerce import Product, Category, Order, OrderItem, ProductInfo
+    from commerce import Product, Category, Order, OrderItem, ProductInfo, ProductPhoto
 
     g = Group()
     g.group_name = u'stroller'
